<?php
namespace Datec\DatecJobmarket\Controller;

use Datec\DatecJobmarket\Domain\Repository\JobentryRepository;
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class JobentryController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * jobentryRepository
	 *
	 * @var \Datec\DatecJobmarket\Domain\Repository\JobentryRepository
	 * @inject
	 */
	protected $jobentryRepository;
	
	/**
	 * jobgroupRepository
	 *
	 * @var \Datec\DatecJobmarket\Domain\Repository\JobgroupRepository
	 * @inject
	 */
	protected $jobgroupRepository;
	
	/**
	 * qualificationRepository
	 *
	 * @var \Datec\DatecJobmarket\Domain\Repository\QualificationRepository
	 * @inject
	 */
	protected $qualificationRepository;
	
	/**
	 * facilityTypeRepository
	 *
	 * @var \Datec\DatecJobmarket\Domain\Repository\FacilityTypeRepository
	 * @inject
	 */
	protected $facilityTypeRepository;
	
	/**
	 * worktimeTypeRepository
	 *
	 * @var \Datec\DatecJobmarket\Domain\Repository\WorktimeTypeRepository
	 * @inject
	 */
	protected $worktimeTypeRepository;
	
	/**
	 * persistence manager
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface
	 * @inject
	 */
	protected $persistenceManager;
	
	/**
	 * $jobgroups
	 */
	protected $jobgroups;
	
	/**
	 * $qualifications
	 */
	protected $qualifications;
	
	/**
	 * $jobentry
	 * 
	 * @var \Datec\DatecJobmarket\Domain\Model\Jobentry
	 */
	protected $jobentry;
	
	/**
	 * $extKey
	 */
	protected $extKey;
	
	/**
	 * $mailService
	 * @var \Datec\DatecJobmarket\Services\MailService
	 * 
	 * @inject
	 */
	protected $mailService;
	
	/**
	 * initialize current action
	 * @return void
	 */
	public function initializeAction() {
		$this->extKey = $this->request->getControllerExtensionKey();
		$this->args = $this->request->getArguments();
		$this->beUser = $this->getBEuser();
	}
	
	/**
	 * initialize create action
	 * 
	 * @return void
	 */
	protected function initializeCreateAction() {		
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize new action
	 * 
	 * @return void
	 */
	protected function initializeNewAction() {		
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize update action
	 *
	 * @return void
	 */
	protected function initializeUpdateAction() {
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
						'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
						\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
						$this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize delete action
	 *
	 * @return void
	 */
	protected function initializeDeleteAction() {
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
			->allowAllProperties()
			->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
			);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
			->forProperty('beginfrom')
			->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
					$this->settings['display']['dateFormat']
			);
			$this->arguments['jobentry']
			->getPropertyMappingConfiguration()
			->forProperty('limitedto')
			->setTypeConverterOption(
					'TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter',
					\TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter::CONFIGURATION_DATE_FORMAT,
					$this->settings['display']['dateFormat']
			);
		}
	}
	
	/**
	 * action searchForm
	 * 
	 * @return void
	 */
	public function searchFormAction() {
		$this->setJobgroupOptions(TRUE, TRUE);
		
		if ($GLOBALS['TSFE']->id == $this->settings['showExportPid']) {
			$this->forward('showExport', 'Jobentry', 'DatecJobmarket');
		}
		
		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('searchArguments', $this->args);
	}
	
	/**
	 * action search
	 *
	 * @return void
	 */
	public function searchAction() {
		if($this->request->hasArgument('newAction')) {
			$this->redirect('new', 'Jobentry', 'datecjobmarket', $this->args);
		}
		$this->setJobgroupOptions(TRUE);						
		$searchParams = array();
		$searchParams['jobtype'] = $this->args['jobtype'];		
		$searchParams['jobgroups'] = $this->args['jobgroups'];		
		$searchParams['zipcode'] = $this->args['zipSearchArea'];
		$searchParams['workarea'] = $this->args['zipSearchArea'];
		if($this->beUser) {
			$searchParams['hidden'] = 1;
		}
		
		$jobentries = $this->jobentryRepository->searchJobentries($searchParams);
		if ($jobentries === FALSE) {
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		} 
		else if (count($jobentries) < 1 || count($jobentries) === FALSE) {
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.searchNone',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		}
		else {
			$this->view->assign('jobentries', $jobentries);
		}		
		
		$this->view->assign('beUser', $this->beUser);
		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('searchArguments', $this->args);
	}

	/**
	 * action new
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * @dontvalidate $jobentry
	 * @return void
	 */
	public function newAction(\Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry = NULL) {		
		$this->setJobgroupOptions();
		$this->setQualificationOptions();
		
		$facilityTypesResult = $this->facilityTypeRepository->findAll();
		if ($facilityTypesResult) {
			$this->view->assign("facilityTypes", $facilityTypesResult);
		}
		
		$worktimeTypesResult = $this->worktimeTypeRepository->findAll();
		if ($worktimeTypesResult) {
			$this->view->assign("worktimeTypes", $worktimeTypesResult);
		}

		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('qualifications', $this->qualifications);
		$this->view->assign('jobentry', $jobentry);
		$this->view->assign('settings', $this->settings);
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}
	
	/**
	 * action create
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * @return void
	 */
	public function createAction(\Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry) {
		if($this->request->hasArgument('back_button')) {
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		} 
		
		if (isset($_POST['mail']) && $_POST['mail'] != '') { // spam protection field, honeypot should be empty
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.spam',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
		} else {		
			$workarea = str_replace(' ','',$jobentry->getWorkarea()); // remove spaces for DB
			$jobentry->setWorkarea($workarea);		
			
			$startDateTime = new \DateTime();
			$endDateTime = clone $startDateTime;
			$endDateTime->modify('+'.$this->settings['jobentry']['defaultValidToDays'].' day');
			$jobentry->setStarttime($startDateTime);
			$jobentry->setEndtime($endDateTime);
			
			if ($this->settings['jobentry']['defaultFacilityType'] != 0) {
				$facilityTypeResult = $this->facilityTypeRepository->findByUid($this->settings['jobentry']['defaultFacilityType']);
				if ($facilityTypeResult) {
					$jobentry->setFacilityType($facilityTypeResult);
				}
			}
			
			if ($this->settings['jobentry']['defaultWorktimeType'] != 0) {
				$worktimeTypeResult = $this->worktimeTypeRepository->findByUid($this->settings['jobentry']['defaultWorktimeType']);
				if ($worktimeTypeResult) {
					$jobentry->setWorktimeType($worktimeTypeResult);
				}
			}
				
			$this->jobentryRepository->add($jobentry);
			$this->persistenceManager->persistAll();		
			$extensionName = $this->request->getControllerExtensionName();
			$msg = $this->mailService->generateInfoMail($jobentry, $this->extKey, $extensionName);
			$this->mailService->sendInfoMail($jobentry, $msg, $this->settings, $this->extKey);
			
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.created',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::OK);
		}
		$this->redirect('searchForm', 'Jobentry', 'datecjobmarket');
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}
	
	/**
	 * action hide
	 *
	 * @return void
	 */
	public function hideAction() {
		if ($this->beUser) {	
			if (is_numeric($this->args['jobentry'])) {
				$jobentryId = $this->args['jobentry'];
			} else if (is_array($this->args['jobentry']))  {
				$jobentryId = $this->args['jobentry']['__identity'];
			}
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
			if ($this->jobentry) {
				$hidden = ($this->jobentry->getHidden() == 1) ? 0 : 1;
				$this->jobentry->setHidden($hidden);
				
				$updateResult = $this->jobentryRepository->update($this->jobentry);		
				if ($updateResult === FALSE) {
					$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hiddenError',$this->extKey, '', \TYPO3\CMS\Core\Messaging\FlashMessage::OK).': '.$this->jobentry->getUid().' - "'.$this->jobentry->getTitle().'"', '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
				} else {
					$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hidden',$this->extKey).': '.$this->jobentry->getUid().' - "'.$this->jobentry->getTitle().'"', '', \TYPO3\CMS\Core\Messaging\FlashMessage::OK);
				}
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			}
		}	
		$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
	}
	
	/**
	 * action show
	 * 
	 * @return void
	 */
	public function showAction() {
		if($this->request->hasArgument('back_button')) {
			$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
		}
		
		if (is_numeric($this->args['jobentry'])) {
			$jobentryId = $this->args['jobentry'];
		} else if (is_array($this->args['jobentry']))  {
			$jobentryId = $this->args['jobentry']['__identity'];
		}
		
		if($this->request->hasArgument("contact")) {
			$this->redirect('contactform', 'Jobentry', 'datecjobmarket', array('jobId' => $jobentryId));
		}
		
		if($this->beUser) {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		} else {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId, false, array('hidden'));
		}
		
		if($this->jobentry) {
			if($this->request->hasArgument('login_edit')) {
				if (!empty($this->args['ShowForm']['password'])) {
					if ($this->args['ShowForm']['password'] == $this->jobentry->getPassword()) {
						unset($this->args['ShowForm']['password']);
						$this->args['authHash'] = md5($this->jobentry->getPassword());
						
						if ($this->settings['security']['userEmailCompare']) { // compares email to secure ownership of the jobentry, requires frontend login with same email address
							if ($GLOBALS['TSFE']->user['email'] == $this->jobentry->getEmail()) {
								$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
							} else {
								$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.emailWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
							}
						} else {
							$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
						}
					} else {
						$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.passwordWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
					}
				} else {
					$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.passwordMissing',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
				}			
			}
		} else {
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
		}
		
		if($this->request->hasArgument('edit') && $this->beUser) {
			$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
		}
		
		if($this->request->hasArgument('edit') && isset($this->args['authHash'])) {
			if ($this->args['authHash'] == md5($this->jobentry->getPassword())) {
				$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
			}
		}
		
		$this->view->assign('beUser', $this->beUser);
		$this->view->assign('jobentry', $this->jobentry);
		$this->view->assign('searchArguments', $this->args['searchArguments']);
	}
	
	/**
	 * action edit
	 *
	 * @param 
	 * @return void
	 */
	public function editAction() {
		if (is_numeric($this->args['jobentry'])) {
			$jobentryId = $this->args['jobentry'];
		} else if (is_array($this->args['jobentry']))  {
			$jobentryId = $this->args['jobentry']['__identity'];
		}
		
		if($this->beUser) {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId, true, array('hidden'));
		} else {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		}
		
		if($this->jobentry && $this->args['authHash'] || $this->beUser) {
			if ($this->args['authHash'] == md5($this->jobentry->getPassword()) || $this->beUser) {
				$this->setJobgroupOptions();
				$this->setQualificationOptions();
				
				$facilityTypesResult = $this->facilityTypeRepository->findAll();
				if ($facilityTypesResult) {
					$this->view->assign("facilityTypes", $facilityTypesResult);
				}
				
				$worktimeTypesResult = $this->worktimeTypeRepository->findAll();
				if ($worktimeTypesResult) {
					$this->view->assign("worktimeTypes", $worktimeTypesResult);
				}
				
				$this->view->assign('authHash', md5($this->jobentry->getPassword()));
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
			}
		}
		
		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('qualifications', $this->qualifications);
		$this->view->assign('jobentry', $this->jobentry);
		$this->view->assign('searchArguments', $this->args['searchArguments']);
		$this->view->assign('settings', $this->settings);
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}

	/** 
	 * action update
	 * 
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * @dontvalidate $jobentry
	 * @return void
	 */
	public function updateAction(\Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry) {
		if($this->request->hasArgument('back_button')) {
			$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
		}
		
		if($this->request->hasArgument('deleteAction') && isset($this->args['authHash'])) {
			if ($this->args['authHash'] == md5($jobentry->getPassword())) {
				$this->redirect('delete', 'Jobentry', 'datecjobmarket', $this->args);
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
			}	
		}
		
		if($this->request->hasArgument('updateAction') && isset($this->args['authHash'])){
			
			if ($this->settings['jobentry']['resetStarttimeAndEndtimeOnUpdate']) {
				$startDateTime = new \DateTime();
				$startDateTime->modify('-1 minute'); // prevents object from being not found right NOW
				$endDateTime = clone $startDateTime;
				$endDateTime->modify('+'.$this->settings['jobentry']['defaultValidToDays'].' day');
				$jobentry->setStarttime($startDateTime);
				$jobentry->setEndtime($endDateTime);
			}
			$this->jobentryRepository->update($jobentry);
			
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.updated',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::OK);
		}	
		$this->args['jobentry']['__identity'] = $jobentry->getUid();
		$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
	}
	
	/**
	 * action delete 
	 * 
	 * @return void
	 */
	public function deleteAction() {
		if (is_numeric($this->args['jobentry'])) {
			$jobentryId = $this->args['jobentry'];
		} else if (is_array($this->args['jobentry']))  {
			$jobentryId = $this->args['jobentry']['__identity'];
		}
		$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		if ($this->jobentry) {
			if(isset($this->args['authHash'])) {
				if ($this->args['authHash'] == md5($this->jobentry->getPassword())) {
					
					$this->jobentryRepository->remove($this->jobentry);
					$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.removed',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::OK);
				} else {
					$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::WARNING);
				}	
			}	
		} else {
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
		}
		
		$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
	}
	
	/**
	 * action showExport
	 *
	 * @return void
	 */
	public function showExportAction() {
		// load split, because this is more performant in the output
		if($this->beUser) {
			$jobentryRequests = $this->jobentryRepository->findExportable(1);
			$jobentryOffers = $this->jobentryRepository->findExportable(2);
			if ($jobentryRequests) {
				$this->view->assign('jobentryRequests', $jobentryRequests);			
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			}			
			if ($jobentryOffers) {			
				$this->view->assign('jobentryOffers', $jobentryOffers);
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			}			
		} else {
			$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.noBeUser',$this->extKey), '', \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
		}			
	}
	
	/**
	 * Display Contact Form
	 * @return void
	 */
	public function contactFormAction() {
		$this->view->assign("lang", $GLOBALS['TSFE']->lang);
		$this->view->assign("settings", $this->settings);
		$this->view->assign("jobId", $this->args['jobId']);
	}
	
	/**
	 * @return void
	 */
	public function sendContactAction() {
		$errorcount = 0;
		if($this->request->hasArgument("message")) {
			if(empty($this->request->getArgument("message"))) {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate("tx_datecjobmarket.messages.noMessage", $this->extKey), "", \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
				$errorcount++;
			}
		}
		if($this->request->hasArgument("email")) {
			if(empty($this->request->getArgument("email"))) {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate("tx_datecjobmarket.messages.noMail",$this->extKey), "", \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
				$errorcount++;
			}
		}
		
		if($this->request->hasArgument("mailSpam")) {
			if(!empty($this->request->getArgument("mailSpam"))) {
				$errorcount++;
			}
		}
		if($errorcount == 0) {
			$jobentry = $this->jobentryRepository->findByUid($this->request->getArgument("jobId"));
			$mailAdress = $this->request->getArgument("email");
			$contactMsg = $this->request->getArgument("message");
			$extensionName = $this->request->getControllerExtensionName();
			$subject = \TYPO3\CMS\Extbase\utility\LocalizationUtility::translate("tx_datecjobmarket.mail.subjects.contactMail", $this->extKey,array(0 => $jobentry->getTitle()));
			$msg = $this->mailService->generateUserMail($mailAdress, $contactMsg,$extensionName);
			if($this->mailService->sendContactMail($msg, $jobentry, $subject, $this->settings)) {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate("tx_datecjobmarket.messages.contact.sendComplete",$this->extKey), "", \TYPO3\CMS\Core\Messaging\FlashMessage::OK);
			} else {
				$this->addFlashMessage(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate("tx_datecjobmarket.messages.contact.sendError", $this->extKey), "", \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			}
		}
	
	}
	
	/**
	 * set jobgroup options
	 * 
	 * @param boolean $prependAllOption puts an 'all' option before the rest
	 * @param boolean $checkAll all options should be checked if not in request arguments
	 * @return void
	 */
	private function setJobgroupOptions($prependAllOption = FALSE, $checkAll = FALSE) {	
		$jobgroupsResult = $this->jobgroupRepository->findAll();
		if (isset($this->jobentry)) {
			$jobentryJobgroups = $this->jobentry->getJobgroups();
		}
		
		if ($jobgroupsResult) {	
			$jobgroupsResult = $jobgroupsResult->toArray();
			
			if (count($jobgroupsResult)) {
				foreach ($jobgroupsResult as $jobgroup) {
					$jobgroups[] = array(
							'value' => $jobgroup->getUid(), 
							'label' => $jobgroup->getName(), 
							'checked' => (isset($this->args['jobgroups']) && !empty($this->args['jobgroups'])) ? in_array($jobgroup->getUid(), $this->args['jobgroups']) : (isset($jobentryJobgroups) ? $jobentryJobgroups->contains($jobgroup) : $checkAll), 
					);
				}
				
				if ($prependAllOption) {
					$jobgroupAll = array(
							'value' => 0, 
							'label' => \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.labels.jobgroup_all',$this->extKey), 
							'checked' => isset($this->args['jobgroupsAll']) ? (($this->args['jobgroupsAll'] === "") ? FALSE : TRUE) : $checkAll, 
					);			
					array_unshift($jobgroups, $jobgroupAll);
				}
						
				$this->jobgroups = $jobgroups;
			}
		}
	}
	
	/**
	 * set qualification options
	 *
	 * @param boolean $checkAll all options should be checked if not in request arguments
	 * @return void
	 */
	private function setQualificationOptions($checkAll = FALSE) {
		$qualificationsResult = $this->qualificationRepository->findAll();
		if (isset($this->jobentry)) {
			$jobentryQualifications = $this->jobentry->getQualifications();
		}
		
		if ($qualificationsResult) {
			$qualificationsResult = $qualificationsResult->toArray();
				
			if (count($qualificationsResult)) {
				foreach ($qualificationsResult as $qualification) {
					$qualifications[] = array(
						'value' => $qualification->getUid(), 
						'label' => $qualification->getName(), 
						'checked' => isset($this->args['qualifications']) ? in_array($qualification->getUid(), $this->args['qualifications']) : (isset($jobentryQualifications) ? $jobentryQualifications->contains($qualification) : $checkAll),
					);
				}
	
				$this->qualifications = $qualifications;
			}
		}
	}
	
	/**
	 * check for be user and retrieve his data
	 * this is needed to determine FE-editing
	 *
	 * @return array $beUser or boolean FALSE if no allowed user found
	 */
	private function getBEuser() {
		if(isset($GLOBALS['BE_USER']->user)) {
			$beUser = $GLOBALS['BE_USER']->user;
			$usersGroups = explode(',',$beUser['usergroup']);
			$allowedGroups = explode(',',$this->settings['allowedBEgroups4FEediting']); // these usergroups are configured to edit in FE
			foreach ($allowedGroups as $allowedGroup) {
				if($beUser['admin'] == 1 || in_array($allowedGroup, $usersGroups)) {
					return $beUser;
				}
			}			
		}
				
		return FALSE;
	}
	
		
	/**
	 * @param string $action
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * 
	 * @return string the URI
	 */
	private function buildControllerActionLink4Jobentry($action, $jobentry) {
		$uriBuilder = $this->controllerContext->getUriBuilder();
		$argumentPrefix = 'tx_datecjobmarket_jobmarket';
		$arguments = array();
		
		$arguments['action'] = $action;
		$arguments['jobentry'] = $jobentry->getUid();
		$arguments['authHash'] = md5($jobentry->getPassword());
		
		return $uriBuilder
			->reset()
			->setArguments(array($argumentPrefix => $arguments))
			->setAddQueryString(TRUE)
			->setArgumentsToBeExcludedFromQueryString(array($argumentPrefix, 'cHash'))
			->setCreateAbsoluteUri(TRUE)
			->build();
	}

}
?>