<?php
namespace Datec\DatecJobmarket\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Jobentry extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

	/**
	 * either 1 = Request or 2 = Offer
	 *
	 * @var \integer
	 */
	protected $jobtype;

	/**
	 * short information
	 *
	 * @var \string
	 */
	protected $title;

	/**
	 * additional information
	 *
	 * @var \string
	 */
	protected $information;

	/**
	 * Storage of jobgroups
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Jobgroup>
	 */
	protected $jobgroups;

	/**
	 * Storage of qualifications
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Qualification>
	 */
	protected $qualifications;
	
	/**
	 * Name of person to contact
	 *
	 * @var \string
	 */
	protected $contact;
	
	/**
	 * Name of the facility, only jobtype 2
	 *
	 * @var \string
	 */
	protected $facility;
	
	/**
	 * Type of the facility, only if facility is relevant
	 *
	 * @var \Datec\DatecJobmarket\Domain\Model\FacilityType
	 */
	protected $facilityType;

	/**
	 * comma-seperated list of zip codes, only jobtype 1
	 *
	 * @var \string
	 */
	protected $workarea;
	
	/**
	 *
	 * @var int
	 */
	protected $worktime;
	
	/**
	 * Type of the work, like full-time or part-time
	 *
	 * @var \Datec\DatecJobmarket\Domain\Model\WorktimeType
	 */
	protected $worktimeType;

	/**
	 * street
	 *
	 * @var \string
	 */
	protected $street;

	/**
	 * zipcode
	 *
	 * @var \string
	 */
	protected $zipcode;

	/**
	 * city
	 *
	 * @var \string
	 */
	protected $city;

	/**
	 * phone1
	 *
	 * @var \string
	 */
	protected $phone1;

	/**
	 * phone2
	 *
	 * @var \string
	 */
	protected $phone2;

	/**
	 * fax
	 *
	 * @var \string
	 */
	protected $fax;

	/**
	 * email
	 *
	 * @var \string
	 */
	protected $email;
	
	/**
	 * password
	 *
	 * @var \string
	 */
	protected $password;
	
	/**
	 * @var \DateTime
	 */
	protected $starttime;
	
	/**
	 * @var \DateTime
	 */
	protected $endtime;
	
	/**
	 * @var \DateTime
	 */
	protected $beginfrom;
	
	/**
	 * @var \DateTime
	 */
	protected $limitedto;

	/**
	 * @var \integer
	 */
	protected $hidden = 0;	
	
	/**
	 * @var \integer
	 */
	protected $uid;
	
	/**
	 * @var \boolean
	 */
	protected $exportable;
	
	/**
	 * __construct
	 */
	public function __construct() {
		$this->jobgroups = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$this->qualifications = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
	}
	
	/**
	 * Returns the jobtype
	 *
	 * @return \integer $jobtype
	 */
	public function getJobtype() {
		return $this->jobtype;
	}

	/**
	 * Sets the jobtype
	 *
	 * @param \integer $jobtype
	 * @return void
	 */
	public function setJobtype($jobtype) {
		$this->jobtype = $jobtype;
	}

	/**
	 * Returns the title
	 *
	 * @return \string $title
	 */
	public function getTitle() {
		return $this->title;
	}

	/**
	 * Sets the title
	 *
	 * @param \string $title
	 * @return void
	 */
	public function setTitle($title) {
		$this->title = $title;
	}

	/**
	 * Returns the information
	 *
	 * @return \string $information
	 */
	public function getInformation() {
		return $this->information;
	}

	/**
	 * Sets the information
	 *
	 * @param \string $information
	 * @return void
	 */
	public function setInformation($information) {
		$this->information = $information;
	}

	/**
	 * Adds a Jobgroup
 	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobgroup $jobgroup
	 * @return void
  	 */
	public function addJobgroup(\Datec\DatecJobmarket\Domain\Model\Jobgroup $jobgroup) {
		$this->jobgroups->attach($jobgroup);
	}
 
	/**
	 * Removes a Jobgroup
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobgroup $jobgroup The Jobgroup to be removed
	 * @return void
	 */
	public function removeJobgroup(\Datec\DatecJobmarket\Domain\Model\Jobgroup $jobgroup) {
		$this->jobgroups->detach($jobgroup);
	}
 
	/**
	 * Returns the jobgroups
	 *
	 * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Jobgroups> $jobgroups
	 */
	public function getJobgroups() {
		return $this->jobgroups;
	}
 
	/**
	 * Sets the jobgroups
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Jobgroups> $jobgroups
	 * @return void
	 */
	public function setJobgroups(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $jobgroups) {
		$this->jobgroups = $jobgroups;
	}
	
	/**
	 * Adds a Qualification
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Qualification $qualification
	 * @return void
	 */
	public function addQualification(\Datec\DatecJobmarket\Domain\Model\Qualification $qualification) {
		$this->qualifications->attach($qualification);
	}
	
	/**
	 * Removes a Qualification
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Qualification $qualification The Qualification to be removed
	 * @return void
	 */
	public function removeQualification(\Datec\DatecJobmarket\Domain\Model\Qualification $qualification) {
		$this->qualifications->detach($qualification);
	}
	
	/**
	 * Returns the qualifications
	 *
	 * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Qualifications> $qualifications
	 */
	public function getQualifications() {
		return $this->qualifications;
	}
	
	/**
	 * Sets the qualifications
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Datec\DatecJobmarket\Domain\Model\Qualifications> $qualifications
	 * @return void
	 */
	public function setQualifications(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $qualifications) {
		$this->qualifications = $qualifications;
	}
	
	/**
	 * Returns the contact
	 *
	 * @return \string $contact
	 */
	public function getContact() {
		return $this->contact;
	}
	
	/**
	 * Sets the contact
	 *
	 * @param \string $contact
	 * @return void
	 */
	public function setContact($contact) {
		$this->contact = $contact;
	}

	/**
	 * Returns the facility
	 *
	 * @return \string $facility
	 */
	public function getFacility() {
		return $this->facility;
	}

	/**
	 * Sets the facility
	 *
	 * @param \string $facility
	 * @return void
	 */
	public function setFacility($facility) {
		$this->facility = $facility;
	}
	
	/**
	 * Returns the facilityType
	 *
	 * @return \Datec\DatecJobmarket\Domain\Model\FacilityType $facilityType
	 */
	public function getFacilityType() {
		return $this->facilityType;
	}
	
	/**
	 * Sets the facilityType
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\FacilityType $facilityType
	 * @return void
	 */
	public function setFacilityType($facilityType) {
		$this->facilityType = $facilityType;
	}

	/**
	 * Returns the workarea
	 *
	 * @return \string $workarea
	 */
	public function getWorkarea() {
		return $this->workarea;
	}

	/**
	 * Sets the workarea
	 *
	 * @param \string $workarea
	 * @return void
	 */
	public function setWorkarea($workarea) {
		$this->workarea = $workarea;
	}
	
	
	
	/**
	 * Returns the worktimeType
	 *
	 * @return \Datec\DatecJobmarket\Domain\Model\WorktimeType $worktimeType
	 */
	public function getWorktimeType() {
		return $this->worktimeType;
	}
	
	/**
	 * Sets the worktimeType
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\WorktimeType $worktimeType
	 * @return void
	 */
	public function setWorktimeType($worktimeType) {
		$this->worktimeType = $worktimeType;
	}
	
	/**
	 * Set worktime
	 * @param int $worktime
	 * @return void
	 */
	public function setWorktime($worktime) {
		$this->worktime = $worktime;
	}
	
	/**
	 * Get worktime
	 * @return int worktime
	 */
	public function getWorktime() {
		return $this->worktime;
	}
	
	/**
	 * Returns the street
	 *
	 * @return \string $street
	 */
	public function getStreet() {
		return $this->street;
	}

	/**
	 * Sets the street
	 *
	 * @param \string $street
	 * @return void
	 */
	public function setStreet($street) {
		$this->street = $street;
	}

	/**
	 * Returns the zipcode
	 *
	 * @return \string $zipcode
	 */
	public function getZipcode() {
		return $this->zipcode;
	}

	/**
	 * Sets the zipcode
	 *
	 * @param \string $zipcode
	 * @return void
	 */
	public function setZipcode($zipcode) {
		$this->zipcode = $zipcode;
	}

	/**
	 * Returns the city
	 *
	 * @return \string $city
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * Sets the city
	 *
	 * @param \string $city
	 * @return void
	 */
	public function setCity($city) {
		$this->city = $city;
	}

	/**
	 * Returns the phone1
	 *
	 * @return \string $phone1
	 */
	public function getPhone1() {
		return $this->phone1;
	}

	/**
	 * Sets the phone1
	 *
	 * @param \string $phone1
	 * @return void
	 */
	public function setPhone1($phone1) {
		$this->phone1 = $phone1;
	}

	/**
	 * Returns the phone2
	 *
	 * @return \string $phone2
	 */
	public function getPhone2() {
		return $this->phone2;
	}

	/**
	 * Sets the phone2
	 *
	 * @param \string $phone2
	 * @return void
	 */
	public function setPhone2($phone2) {
		$this->phone2 = $phone2;
	}

	/**
	 * Returns the fax
	 *
	 * @return \string $fax
	 */
	public function getFax() {
		return $this->fax;
	}

	/**
	 * Sets the fax
	 *
	 * @param \string $fax
	 * @return void
	 */
	public function setFax($fax) {
		$this->fax = $fax;
	}

	/**
	 * Returns the email
	 *
	 * @return \string $email
	 */
	public function getEmail() {
		return $this->email;
	}

	/**
	 * Sets the email
	 *
	 * @param \string $email
	 * @return void
	 */
	public function setEmail($email) {
		$this->email = $email;
	}
	
	/**
	 * Returns the password
	 *
	 * @return \string $password
	 */
	public function getPassword() {
		return $this->password;
	}
	
	/**
	 * Sets the password
	 *
	 * @param \string $password
	 * @return void
	 */
	public function setPassword($password) {
		$this->password = $password;
	}
	
	/**
	 * Returns the point in time from which this jobentry is visible.
	 *
	 * @return \DateTime the start date and time
	 */
	public function getStarttime() {
		return $this->starttime;
	}

	/**
	 * Sets the point in time from which this jobentry is visible.
	 *
	 * @param \DateTime $dateAndTime
	 * @return void
	 */
	public function setStarttime($dateAndTime=0) {
		$this->starttime = $dateAndTime;
	}

	/**
	 * Returns the point in time before which this jobentry is visible.
	 *
	 * @return \DateTime the end date and time
	 */
	public function getEndtime() {
		return $this->endtime;
	}

	/**
	 * Sets the point in time before which this jobentry is visible.
	 *
	 * @param \DateTime $dateAndTime
	 * @return void
	 */
	public function setEndtime($dateAndTime=0) {
		$this->endtime = $dateAndTime;
	}
	
	/**
	 * Returns the point in time from which this jobentry is valid.
	 *
	 * @return \DateTime the start date and time
	 */
	public function getBeginfrom() {
		return $this->beginfrom;
	}
	
	/**
	 * Sets the point in time from which this jobentry is valid.
	 *
	 * @param \DateTime $dateAndTime
	 * @return void
	 */
	public function setBeginfrom($dateAndTime=0) {
		$this->beginfrom = $dateAndTime;
	}
	
	/**
	 * Returns the point in time before which this jobentry is valid.
	 *
	 * @return \DateTime the end date and time
	 */
	public function getLimitedto() {
		return $this->limitedto;
	}
	
	/**
	 * Sets the point in time before which this jobentry is valid.
	 *
	 * @param \DateTime $dateAndTime
	 * @return void
	 */
	public function setLimitedto($dateAndTime=0) {
		$this->limitedto = $dateAndTime;
	}
	
	/**
	 * Returns absolute visibility for jobentry.
	 *
	 * @return \integer $hidden
	 */
	public function getHidden() {
		return $this->hidden;
	}
	
	/**
	 * Sets absolute visibility for jobentry.
	 *
	 * @param \integer $hidden default = 0
	 * @return void
	 */
	public function setHidden($hidden = 0) {
		$this->hidden = $hidden;
	}
	
	/**
	 * @return \integer $uid
	 */
	public function getUid() {
		return $this->uid;
	}
	
	/**
	 * @param \integer $uid
	 * @return void
	 */
	public function setUid($uid) {
		$this->uid = $uid;
	}
	
	/**
	 * @return \boolean $exportable
	 */
	public function isExportable() {
		return $this->exportable;
	}
	
	/**
	 * @return \boolean $exportable
	 */
	public function getExportable() {
		return $this->exportable;
	}
	
	/**
	 * @param \boolean $exportable
	 * @return void
	 */
	public function setExportable($exportable) {
		$this->exportable = $exportable;
	}
	
	

}
?>