<?php
namespace Datec\DatecJobmarket\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class JobentryRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {
	
	protected $defaultOrderings = array(
			'starttime' => \TYPO3\CMS\Extbase\Persistence\QueryInterface::ORDER_DESCENDING
	 );
	
	/**
	 * overrides default settings initialisation
	 * this is essential to work with hidden objects
	 */
	 public function initializeObject() {
	 	$query = $this->createQuery();	 	
        $defaultQuerySettings = $query->getQuerySettings();
        $defaultQuerySettings->setIgnoreEnableFields(TRUE);
        $defaultQuerySettings->setEnableFieldsToBeIgnored(array('starttime','endtime','disabled'));
        $this->setDefaultQuerySettings($defaultQuerySettings);
        unset($query);
	}
	
	/**
	 * action search
	 *
	 * @param $searchParams array
	 * @return result
	 */
	public function searchJobentries($searchParams) {
		$result = FALSE;
		$constraints = array();
		
		$query = $this->createQuery();
		
		if (isset($searchParams['jobtype'])) {
			$constraints[] = $query->equals('jobtype', $searchParams['jobtype']);
		}
		
		if (isset($searchParams['jobgroups']) && !empty($searchParams['jobgroups'])) {
			$jobgroupConstraints = array();
			foreach ($searchParams['jobgroups'] as $jobgroup) {
				$jobgroupConstraints[] = $query->contains('jobgroups', $jobgroup);
			}
			$constraints[] = $query->logicalOr($jobgroupConstraints);
		}
		
		if ((isset($searchParams['zipcode']) && !empty($searchParams['zipcode'])) && (isset($searchParams['workarea']) && !empty($searchParams['workarea']))) {
			$locationConstraints = array();
			$locationConstraints[] = $query->like('zipcode', $searchParams['zipcode']."%");
			$locationConstraints[] = $query->like('workarea', $searchParams['workarea']."%");
			$locationConstraints[] = $query->like('workarea', "%,".$searchParams['workarea']."%");
			$constraints[] = $query->logicalOr($locationConstraints);
		}
		
		if (isset($searchParams['hidden']) && !empty($searchParams['hidden'])) {
			$hiddenConstraints = array();
			$hiddenConstraints[] = $query->equals('hidden', 0);
			$hiddenConstraints[] = $query->equals('hidden', $searchParams['hidden']);
			$constraints[] = $query->logicalOr($hiddenConstraints);
		} else {
			$constraints[] = $query->equals('hidden', 0);
		}
		
		$time = time();
		$constraints[] = $query->lessThanOrEqual('starttime', $time);
		$constraints[] = $query->greaterThanOrEqual('endtime', $time);
		
		if (count($constraints)) {			
			$result = $query->matching($query->logicalAnd($query->logicalAnd($constraints)))->execute();
		}		
		
		unset($query);
		
		return $result;
	}
	
	/**
	 * Finds all object with the 'exportable' property set to true.
	 * 
	 * @param int $jobtype also filter by jobtype (optional)
	 * @param boolean $ingnoreEnableFields on TRUE will ignore starttime, endtime and disabled (optional)
	 * @return \TYPO3\CMS\Extbase\Persistence\QueryResultInterface|array The query result object or an array if $returnRawQueryResult is TRUE
	 */
	public function findExportable($jobtype = NULL, $ingnoreEnableFields = FALSE) {
		$constraints = array();
		$query = $this->createQuery();	
		$querySettings = $query->getQuerySettings();
		$querySettings->setIgnoreEnableFields($ingnoreEnableFields);
		$query->setQuerySettings($querySettings);
		
		if ($jobtype) {
			$constraints[] = $query->equals('jobtype', $jobtype);
		}
		$constraints[] = $query->equals('exportable', 1);
		$constraints[] = $query->equals('hidden',0);
		
		$time = time();
		$constraints[] = $query->lessThanOrEqual('starttime', $time);
		$constraints[] = $query->greaterThanOrEqual('endtime', $time);
		
		
		return $query->matching($query->logicalAnd($query->logicalAnd($constraints)))->execute();
	}
	
	/**
	 * Finds an object matching the given identifier.
	 *
	 * @param integer $uid The identifier of the object to find
	 * @param boolean $includeDeleted include deleted in search, defaults to FALSE
	 * @param boolean $ignoreEnableFields Fields that should be ignored(optional)
	 * @return object The matching object if found, otherwise NULL
	 */
	public function findByUid($uid, $includeDeleted = FALSE, $ignoreFields = array()) {
		$query = $this->createQuery();
		$defaultQuerySettings = $query->getQuerySettings();
		$defaultQuerySettings->setIncludeDeleted($includeDeleted);
		$defaultQuerySettings->setEnableFieldsToBeIgnored($ignoreFields);
		$this->setDefaultQuerySettings($defaultQuerySettings);
		$object = $query->matching($query->equals('uid', $uid))->execute()->getFirst();
		
		return $object;
	}
	
}
?>