<?php
namespace Datec\DatecJobmarket\Services;

/**
 *
 * @package datec_onlinetrainings
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class MailService implements \TYPO3\CMS\Core\SingletonInterface  {
	/**
	 * $configurationManager
	 * @var \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface
	 * @inject
	 */
	protected $configurationManager;
	
	/**
	 * Sends mail with message to an intern recipients.
	 * 
	 * @param string $subject Subject of message
	 * @param string $msg Message text
	 * @param string $recipientMail Email address of recipient
	 * @param string $recipientName Name of recipient
	 * @param array $settings Plugin configuration
	 * 
	 * @return boolean Message was send
	 */
	public function sendInternMail($subject, $msg, $settings) {		
		$message = new \TYPO3\CMS\Core\Mail\MailMessage();
		$message->setFrom(array($settings['mail']['internMailFrom'] => $settings['mail']['internMailFromName']));
		$message->setTo(array($settings['mail']['internMailTo'] => ''));
		if ($settings['mail']['sendSupportInternMail'] == 1) {
			$message->setBcc(array($settings['mail']['supportInternMailTo'] => ''));
		}
		$message->setSubject($subject);
		$message->setBody($msg,'text/html', 'utf-8');
		
		$message->send();
		if($message->isSent()) {
			return TRUE;
		}
	
		return FALSE;
	}
	
	/**
	 * send informative mail to intern recipients
	 *
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 *
	 * @return boolean $sendMail success if message is sent
	 */
	public function sendInfoMail($jobentry, $msg, $settings, $extKey){
		
		$facilityStr = "";
		$locationStr = "";
	
		
		$subject = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.mail.subjects.infoMail',$extKey);
		$sendMail = \Datec\DatecJobmarket\Services\MailService::sendInternMail($subject, $msg, $settings);
	
		return $sendMail;
	}
	
	/**
	 * Generate the HTML Info E-Mail
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * @param string $extKey
	 * @return string
	 */
	public function generateInfoMail($jobentry, $extKey, $extensionName) {
		$mailView = new \TYPO3\CMS\Fluid\View\StandaloneView();
		$templateName = "/Email/InfoMail.html";
		$extbaseFrameworkConfiguration = $this->configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_FRAMEWORK);
		$templateRootPath = \TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($extbaseFrameworkConfiguration['view']['templateRootPath']);
		$templatePathAndFilename = $templateRootPath.$templateName;
		
		$mailView->setTemplatePathAndFilename($templatePathAndFilename);
		
		$mailView->getRequest()->setControllerExtensionName($extensionName);
		
		$properties = $jobentry->_getCleanProperties();
		$propertiesArr = array();
		foreach ($properties as $propertyName => $propertyValue) {
			if (!empty($propertyValue) && $propertyName != 'uid' && $propertyName != 'pid' && $propertyName != 'hidden' && $propertyName != 'starttime' && $propertyName != 'endtime') { // only non-empty, non-system properties
				
				$valueStr = "";
				if ($propertyValue instanceof \TYPO3\CMS\Extbase\Persistence\ObjectStorage) {
					foreach ($propertyValue->toArray() as $object) {
						$valueStr .= LF.$object->getName();
					}
					$valueStr .= LF;
				} else if ($propertyValue instanceof \Datec\DatecJobmarket\Domain\Model\FacilityType || $propertyValue instanceof \Datec\DatecJobmarket\Domain\Model\WorktimeType) {
					$valueStr = $propertyValue->getName();
				} else if ($propertyValue instanceof \DateTime) {
					$valueStr = $propertyValue->format($this->settings['display']['dateFormat']);
				} else if ($propertyName == 'jobtype') {
					$valueStr = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.jobentry.jobtype.'.$propertyValue,$extKey);
				} else if ($propertyName == 'exportable') {
					$valueStr = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.jobentry.exportable.'.$propertyValue,$extKey);
				}	else if ($propertyName == 'password') {
					$valueStr = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.messages.protected',$extKey);
				} else {
					$valueStr = $propertyValue;
				}
				$propertiesArr['properties'] [] = array(
						"name" => \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.jobentry.'.$propertyName, $extKey),
						"value" => $valueStr,
				);
				//$msg .= \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('tx_datecjobmarket.jobentry.'.$propertyName, $extKey).": ".$valueStr.LF;
			}
		}
		
		
		$mailView->assignMultiple($propertiesArr);
		$emailBody = $mailView->render();
		
		return $emailBody;
		
		
	}
	/**
	 * Send mail to job creater
	 * @param string $message
	 * @param string $mailForm
	 * @param \Datec\DatecJobmarket\Domain\Model\Jobentry $jobentry
	 * @param string $subject
	 */ 
	public function sendContactMail($msg, $jobentry, $subject, $settings) {
		$mail = new \TYPO3\CMS\Core\Mail\MailMessage();
		$mail->setFrom(array($settings['mail']['contactMailFromName'] => $settings['mail']['contactMailFrom']));
		$mail->setTo($jobentry->getEmail(), '');
		
		$mail->setBody($msg, 'text/html', 'utf-8');
		$mail->setSubject($subject);
		
		$mail->send();
		if($mail->isSent()) {
			return true;
		} else {
			return false;
		}
		
	}
	
	/**
	 * Generate a HTML template for contact mail
	 */
	public function generateUserMail($mailAdress, $contactMsg, $extensionName) {
		$mailView = new \TYPO3\CMS\Fluid\View\StandaloneView();
		$templateName = '/Email/ContactMail.html';
		$extbaseFrameworkConfiguration = $this->configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_FRAMEWORK);
		$templateRootPath = \TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($extbaseFrameworkConfiguration['view']['templateRootPath']);
		$templatePathAndFilename = $templateRootPath.$templateName;
		
		$mailView->setTemplatePathAndFilename($templatePathAndFilename);
		$mailView->getRequest()->setControllerExtensionName($extensionName);
		$fullUrl = \TYPO3\CMS\Core\Utility\GeneralUtility::getIndpEnv("TYPO3_SITE_URL");
		
		$contactarr = array('mailAdress' => $mailAdress,
							'msg' => $contactMsg);
		
		$mailView->assignMultiple($contactarr);
		$emailBody = $mailView->render();
		$emailBody = nl2br($emailBody);
		return $emailBody;
		
	}
	
}
?>